Struct Exmin
#[repr(transparent)]pub struct Exmin(pub u32);Tuple Fields
0: u32Implementations
impl Exmin
impl Exmin
pub const fn exminch(&self) -> u8
pub const fn exminch(&self) -> u8
Extremes detector minimum data channel These bits contain information about the channel on which the data is stored into EXMIN[23:0]. Bits are cleared by reading of this register.
pub const fn set_exminch(&mut self, val: u8)
pub const fn set_exminch(&mut self, val: u8)
Extremes detector minimum data channel These bits contain information about the channel on which the data is stored into EXMIN[23:0]. Bits are cleared by reading of this register.